# gamegridp


Gamegridp ist eine in Python programmierte 2D-Grafikengine die für Bildungszwecke gedacht ist.

Viele Konzepte wurden von  [JGameGrid](http://www.aplu.ch/home/apluhomex.jsp?site=45)_
bzw. [Greenfoot](https://www.greenfoot.org/door) übernommen. Im Gegensatz zu Greenfoot bietet
gamegridp keine grafische Benutzeroberfläche.

Eigenschaften
  * gamegridp unterstützt sowohl Pixel-basierte Spiele als auch Spiele mit 
  quadratischen Zellen (z.B. Rouge-Likes)
  * Einfaches Erstellen von Animationen
  * Musik und Soundeffekte
  * Integrierte Konsole für Ausgaben
  * Einfaches Erstellen von GUI-Elementen und Popups

Das Framework steckt zur Zeit noch in den Kinderschuhen und wird in nächster Zeit weiterentwickelt.

Github: https://github.com/asbl/gamegridp
Dokumentation: https://gamegridp.it-teaching.de
